@@ -927,6 +927,7 @@ impl InputState {
         };
         debug!(target: "rustyline", "Vi insert: {:?}", cmd);
         if cmd.is_repeatable_change() {
+            #[allow(clippy::if_same_then_else)]
             if let (Cmd::Replace(..), Cmd::SelfInsert(..)) = (&self.last_cmd, &cmd) {
                 // replacing...
             } else if let (Cmd::SelfInsert(..), Cmd::SelfInsert(..)) = (&self.last_cmd, &cmd) {
@@ -1123,7 +1124,7 @@ impl InputState {
             if let (n, false) = num_args.overflowing_abs() {
                 (n as RepeatCount, false)
             } else {
-                (RepeatCount::max_value(), false)
+                (RepeatCount::MAX, false)
             }
         } else {
             (num_args as RepeatCount, true)
